# Generated by Django 2.1.1 on 2018-10-19 03:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0007_auto_20181009_0256'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='part',
            unique_together={('number_class', 'number_item', 'number_variation')},
        ),
        migrations.AlterUniqueTogether(
            name='part',
            unique_together={('number_class', 'number_item', 'number_variation', 'organization')},
        ),
    ]
